#
# spec file for package python-svglib
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-svglib
Version:        1.5.1
Release:        1.2
Summary:        Python library for reading and converting SVG
License:        LGPL-3.0-only
URL:            https://github.com/deeplook/svglib
Source:         https://files.pythonhosted.org/packages/source/s/svglib/svglib-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
# SECTION test requirements
BuildRequires:  %{python_module cssselect2 >= 0.2.0}
BuildRequires:  %{python_module lxml}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module reportlab}
BuildRequires:  %{python_module tinycss2 >= 0.6.0}
BuildRequires:  yudit
# /SECTION
Requires:       python-cssselect2 >= 0.2.0
Requires:       python-lxml
Requires:       python-reportlab
Requires:       python-tinycss2 >= 0.6.0
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
%python_subpackages

%description
Pure Python library for reading and converting SVG.

%prep
%setup -q -n svglib-%{version}
# Remove hashbang
sed -i '1{/^#!/d}' svglib/svglib.py
# Make tests a module
touch tests/__init__.py

%build
%pyproject_wheel

%install
%pyproject_install
%{python_clone -a %{buildroot}%{_bindir}/svg2pdf}
%{python_clone -a %{buildroot}%{_mandir}/man1/svg2pdf.1}
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# Skip several tests needing files from internet
%pytest -rs -k 'not (TestWikipediaFlags or TestOtherFiles or (TestW3CSVG and test_convert_pdf_png))'

%post
%{python_install_alternative svg2pdf svg2pdf.1%{ext_man}}

%postun
%python_uninstall_alternative svg2pdf

%files %{python_files}
%doc CHANGELOG.rst README.rst
%license LICENSE.txt
%python_alternative %{_bindir}/svg2pdf
%python_alternative %{_mandir}/man1/svg2pdf.1%{ext_man}
%{python_sitelib}/svglib
%{python_sitelib}/svglib-%{version}.dist-info

%changelog
* Mon Sep 16 2024 Steve Kowalik <steven.kowalik@suse.com>
- Update to 1.5.1:
  * Final fix to conversion from shorthand quadratic to cubic bézier.
  * Add support for ex units (assuming for em/2).
  * Add support for image/jpg embedded images (in addition to image/jpeg).
  * Avoid crash on @import rules in stylesheets. The rules are simply
    ignored.
  * Fix conversion from shorthand quadratic to cubic bézier.
  * Include tests/samples/others/*.svg in source distribution.
  * Render leading and trailing text content in text nodes.
  * Better integration with cssselect2 to support a wider range of CSS
    selectors.
  * Support mmult import from reportlab < 3.5.61.
  * Make zero-length Line, PolyLine and Polygon appear in PDFs when their
    stroke value is non-zero.
  * <symbol> nodes now only appears in documents when they are referenced,
    not on their initial appearance.
  * If only rx or ry is defined on a <rect>, the value is used for both.
  * Support non-prefixed href attribute added in SVG 2.
  * Fixed parsing of empty SVG style nodes.
  * Handle content of multiple SVG style nodes.
  * Better font caching for some font names.
  * Revert to scripts usage instead of console_scripts during setup.
  * dropped support for Python 3.6 and added official support for Python
    3.10.
  * improved support for scientific notation in paths
  * if some path has a color with alpha value, it also sets the default fill
    or stroke opacity of the resulting object.
  * matrix transforms on groups are combined with other transforms instead
    of replacing them.
- Switch to pyproject macros.
- No more globs in %%files.
* Tue Feb 22 2022 Dirk Müller <dmueller@suse.com>
- add missing runtime requires
* Fri Dec 24 2021 John Vandenberg <jayvdb@gmail.com>
- Initial package for v1.1.0
